@@ -13,12 +13,20 @@
 // #include the widget headers so that we can call the get_type() static methods:
 
 #include "appinfo.h"
+#include "application.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
 #include "bufferedoutputstream.h"
 #include "cancellable.h"
+#include "credentials.h"
 #include "datainputstream.h"
 #include "dataoutputstream.h"
+#include "dbusauthobserver.h"
+#include "dbusconnection.h"
+#include "dbusmessage.h"
+#include "dbusmethodinvocation.h"
+#include "dbusownname.h"
+#include "dbusserver.h"
 #include "drive.h"
 #include "emblem.h"
 #include "emblemedicon.h"
@@ -54,6 +62,7 @@
 #include "resolver.h"
 #include "seekable.h"
 #include "settings.h"
+#include "settingsbackend.h"
 #include "socket.h"
 #include "socketaddress.h"
 #include "socketaddressenumerator.h"
@@ -70,6 +79,7 @@
 #include "volumemonitor.h"
 #include "desktopappinfo.h"
 #include "unixconnection.h"
+#include "unixfdlist.h"
 #include "unixinputstream.h"
 #include "unixoutputstream.h"
 
@@ -79,9 +89,16 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType g_app_launch_context_get_type(void);
+GType g_application_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
 GType g_cancellable_get_type(void);
+GType g_credentials_get_type(void);
+GType g_dbus_auth_observer_get_type(void);
+GType g_dbus_connection_get_type(void);
+GType g_dbus_message_get_type(void);
+GType g_dbus_method_invocation_get_type(void);
+GType g_dbus_server_get_type(void);
 GType g_data_input_stream_get_type(void);
 GType g_data_output_stream_get_type(void);
 #ifndef G_OS_WIN32
@@ -124,6 +141,7 @@ GType g_threaded_socket_service_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_connection_get_type(void);
 #endif //G_OS_WIN32
+GType g_unix_fd_list_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_input_stream_get_type(void);
 #endif //G_OS_WIN32
@@ -142,9 +160,16 @@ GQuark g_resolver_error_quark(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Cancellable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Credentials_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusAuthObserver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusMethodInvocation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusServer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
@@ -187,6 +212,7 @@ namespace Gio {  class ThreadedSocketService_Class { public: static Glib::Object
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+namespace Gio {  class UnixFDList_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
@@ -205,9 +231,16 @@ void wrap_init()
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
+  Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
   Glib::wrap_register(g_cancellable_get_type(), &Gio::Cancellable_Class::wrap_new);
+  Glib::wrap_register(g_credentials_get_type(), &Gio::Credentials_Class::wrap_new);
+  Glib::wrap_register(g_dbus_auth_observer_get_type(), &Gio::DBusAuthObserver_Class::wrap_new);
+  Glib::wrap_register(g_dbus_connection_get_type(), &Gio::DBusConnection_Class::wrap_new);
+  Glib::wrap_register(g_dbus_message_get_type(), &Gio::DBusMessage_Class::wrap_new);
+  Glib::wrap_register(g_dbus_method_invocation_get_type(), &Gio::DBusMethodInvocation_Class::wrap_new);
+  Glib::wrap_register(g_dbus_server_get_type(), &Gio::DBusServer_Class::wrap_new);
   Glib::wrap_register(g_data_input_stream_get_type(), &Gio::DataInputStream_Class::wrap_new);
   Glib::wrap_register(g_data_output_stream_get_type(), &Gio::DataOutputStream_Class::wrap_new);
 #ifndef G_OS_WIN32
@@ -250,6 +283,7 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_connection_get_type(), &Gio::UnixConnection_Class::wrap_new);
 #endif //G_OS_WIN32
+  Glib::wrap_register(g_unix_fd_list_get_type(), &Gio::UnixFDList_Class::wrap_new);
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_input_stream_get_type(), &Gio::UnixInputStream_Class::wrap_new);
 #endif //G_OS_WIN32
@@ -260,9 +294,16 @@ void wrap_init()
 
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
+  Gio::Application::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
   Gio::Cancellable::get_type();
+  Gio::Credentials::get_type();
+  Gio::DBusAuthObserver::get_type();
+  Gio::DBusConnection::get_type();
+  Gio::DBusMessage::get_type();
+  Gio::DBusMethodInvocation::get_type();
+  Gio::DBusServer::get_type();
   Gio::DataInputStream::get_type();
   Gio::DataOutputStream::get_type();
 #ifndef G_OS_WIN32
@@ -305,6 +346,7 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Gio::UnixConnection::get_type();
 #endif //G_OS_WIN32
+  Gio::UnixFDList::get_type();
 #ifndef G_OS_WIN32
   Gio::UnixInputStream::get_type();
 #endif //G_OS_WIN32
