@@ -10,22 +10,32 @@
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
 #include "generate_extra_defs.h"
 #include <iostream>
-#include <gio/gio.h>
 
-int main (int argc, char** argv)
+#define G_SETTINGS_ENABLE_BACKEND 1
+#include <gio/gio.h>
+#include <gio/gsettingsbackend.h>
+
+#ifndef G_OS_WIN32
+# include <gio/gunixinputstream.h>
+# include <gio/gunixoutputstream.h>
+# include <gio/gunixconnection.h>
+#endif
+
+int main(int, char**)
 {
   g_type_init ();
 
   std::cout << get_defs(G_TYPE_ASYNC_RESULT)
+            << get_defs(G_TYPE_APPLICATION)
             << get_defs(G_TYPE_CANCELLABLE)
             << get_defs(G_TYPE_BUFFERED_INPUT_STREAM)
             << get_defs(G_TYPE_BUFFERED_OUTPUT_STREAM)
@@ -45,6 +55,11 @@ int main (int argc, char** argv)
             << get_defs(G_TYPE_FILTER_INPUT_STREAM)
             << get_defs(G_TYPE_FILTER_OUTPUT_STREAM)
 
+#ifndef G_OS_WIN32
+            << get_defs(G_TYPE_UNIX_INPUT_STREAM)
+            << get_defs(G_TYPE_UNIX_OUTPUT_STREAM)
+#endif
+
             << get_defs(G_TYPE_INPUT_STREAM)
             << get_defs(G_TYPE_LOADABLE_ICON)
             << get_defs(G_TYPE_MEMORY_INPUT_STREAM)
@@ -52,6 +67,8 @@ int main (int argc, char** argv)
             << get_defs(G_TYPE_MOUNT)
             << get_defs(G_TYPE_MOUNT_OPERATION)
             << get_defs(G_TYPE_SEEKABLE)
+            << get_defs(G_TYPE_SETTINGS)
+            << get_defs(G_TYPE_SETTINGS_BACKEND)
             << get_defs(G_TYPE_SIMPLE_ASYNC_RESULT)
             << get_defs(G_TYPE_THEMED_ICON)
 
@@ -61,6 +78,30 @@ int main (int argc, char** argv)
 
             << get_defs(G_TYPE_VOLUME_MONITOR)
 
+            // network IO classes
+            << get_defs(G_TYPE_DBUS_AUTH_OBSERVER)
+            << get_defs(G_TYPE_DBUS_SERVER)
+            << get_defs(G_TYPE_INET_ADDRESS)
+            << get_defs(G_TYPE_INET_SOCKET_ADDRESS)
+            << get_defs(G_TYPE_SOCKET_ADDRESS)
+            << get_defs(G_TYPE_SOCKET_ADDRESS_ENUMERATOR)
+            << get_defs(G_TYPE_SOCKET_CONNECTABLE)
+            << get_defs(G_TYPE_SRV_TARGET)
+            << get_defs(G_TYPE_RESOLVER)
+            << get_defs(G_TYPE_NETWORK_ADDRESS)
+            << get_defs(G_TYPE_NETWORK_SERVICE)
+            << get_defs(G_TYPE_SETTINGS)
+            << get_defs(G_TYPE_SOCKET)
+            << get_defs(G_TYPE_SOCKET_CLIENT)
+            << get_defs(G_TYPE_SOCKET_CONNECTION)
+            << get_defs(G_TYPE_TCP_CONNECTION)
+#ifndef G_OS_WIN32
+            << get_defs(G_TYPE_UNIX_CONNECTION)
+#endif
+            << get_defs(G_TYPE_SOCKET_LISTENER)
+            << get_defs(G_TYPE_SOCKET_SERVICE)
+            << get_defs(G_TYPE_THREADED_SOCKET_SERVICE)
+
             << std::endl;
   
   return 0;
